
===============
Main Developers
===============

The following lists the authors (active ones are bold) that contributed to upstream (or to some fork) of Perun:

  * **Tomas Fiedor**: |github| `tfiedor <https://github.com/tfiedor>`_ |email| `TomasFiedor@gmail.com <mailto: TomasFiedor@gmail.com>`_ (founder), core
  * **Jiri Pavela**: |github| `JiriPavela <https://github.com/JiriPavela>`_ |email| `JirkaPavela@gmail.com <mailto: JirkaPavela@gmail.com>`_ tracer, core
  * **Ondrej Michal**: |github| `HarryMichal <https://github.com/HarryMichal>`_ [energy profiler](https://gitlab.com/martymichal/sysrapl)
  * **Peter Mocary**: |github| `PeterMocary <https://github.com/PeterMocary>`_ tracer
  * Martina Grzybowska: GUI
  * Vojtech Hajek: C# profiler
  * Matus Liscinsky: fuzzing, perfblowing
  * Radim Podola: |email| `rpodola@gmail.com <mailto: rpodola@gmail.com>`_ memory
  * Simon Stupinsky: |email| `simondestupinsky@gmail.com <mailto: simondestupinsky@gmail.com>`_ models

.. |github| image:: ./figs/icon-github.svg
.. |email| image:: ./figs/icon-email.svg
